.. currentmodule:: solposx


Refraction correction algorithms
================================

Methods of calculating the effect of atmospheric refraction on solar elevation.
Some methods account for secondary effects from temperature and pressure.

.. autosummary::
   :toctree: generated/

   refraction.archer
   refraction.bennett
   refraction.hughes
   refraction.michalsky
   refraction.sg2
   refraction.spa
